[Libreoffice-commits] core.git: 2 commits - sal/osl sal/qa sal/rtl sal/test sal/textenc sw/qa

Andrea Gelmini (via logerrit) logerrit at kemper.freedesktop.org
Fri Aug 2 12:04:35 UTC 2019


 sal/osl/all/filepath.cxx              |    2 +-
 sal/osl/unx/file.cxx                  |    2 +-
 sal/osl/unx/nlsupport.cxx             |    4 ++--
 sal/osl/unx/time.cxx                  |    4 ++--
 sal/osl/w32/file_url.cxx              |    4 ++--
 sal/osl/w32/module.cxx                |    2 +-
 sal/qa/osl/mutex/osl_Mutex.cxx        |    6 +++---
 sal/qa/osl/process/osl_Thread.cxx     |    2 +-
 sal/qa/osl/process/osl_process.cxx    |    2 +-
 sal/rtl/string.cxx                    |    2 +-
 sal/test/bootstrap.pl                 |    2 +-
 sal/textenc/convertsimple.cxx         |    2 +-
 sal/textenc/tcvtjp2.tab               |   20 ++++++++++----------
 sal/textenc/tcvtmb.cxx                |    6 +++---
 sal/textenc/tcvtutf7.cxx              |    6 +++---
 sal/textenc/tencinfo.cxx              |    4 ++--
 sal/textenc/textenc.cxx               |    2 +-
 sw/qa/extras/rtfexport/rtfexport4.cxx |    2 +-
 18 files changed, 37 insertions(+), 37 deletions(-)

New commits:
commit 1f0802c13e835363ff48ee71a18876527321e7d8
Author:     Andrea Gelmini <andrea.gelmini at gelma.net>
AuthorDate: Fri Aug 2 11:30:46 2019 +0200
Commit:     Andrea Gelmini <andrea.gelmini at gelma.net>
CommitDate: Fri Aug 2 14:03:48 2019 +0200

    Fix typo in code
    
    Change-Id: Ie32bb0cf7f987ab57dc03d1485535a1019fd111a
    Reviewed-on: https://gerrit.libreoffice.org/76853
    Reviewed-by: Stephan Bergmann <sbergman at redhat.com>
    Tested-by: Jenkins

diff --git a/sal/test/bootstrap.pl b/sal/test/bootstrap.pl
index 60a306a99c96..5dde94f80154 100644
--- a/sal/test/bootstrap.pl
+++ b/sal/test/bootstrap.pl
@@ -233,7 +233,7 @@ $rc = system "./testbootstrap",
     "AAABBBCCC000",
     '-env:MYBOOTSTRAPTESTVALUE=\u0041\u0041\u0041\u0042\u0042\u0042\u0043\u0043\u0043\u0030\u0030\u0030';
 if (!$rc) {
-    $comment = $comment . "uncode not passed\n";
+    $comment = $comment . "unicode not passed\n";
     $state = 0;
 }
 
commit 7bef1aa72271361921b452559bb5debe3bfcf925
Author:     Andrea Gelmini <andrea.gelmini at gelma.net>
AuthorDate: Fri Aug 2 11:30:01 2019 +0200
Commit:     Andrea Gelmini <andrea.gelmini at gelma.net>
CommitDate: Fri Aug 2 14:03:36 2019 +0200

    Fix typos
    
    Change-Id: Ie183c445bf8a545f59aac7b0e29f72ab679a6cf3
    Reviewed-on: https://gerrit.libreoffice.org/76852
    Tested-by: Jenkins
    Reviewed-by: Andrea Gelmini <andrea.gelmini at gelma.net>

diff --git a/sal/osl/all/filepath.cxx b/sal/osl/all/filepath.cxx
index ae917c6d90ed..afba01739b1b 100644
--- a/sal/osl/all/filepath.cxx
+++ b/sal/osl/all/filepath.cxx
@@ -93,7 +93,7 @@ oslFileError SAL_CALL osl_abbreviateSystemPath( rtl_uString *ustrSystemPath, rtl
 
     rtl_uString_newConcat( pustrCompacted, ustrPath, ustrFile );
 
-    /* Event now if path was compacted to ".../..." it can be to large */
+    /* Event now if path was compacted to ".../..." it can be too large */
 
     uPathWidth += uFileWidth;
 
diff --git a/sal/osl/unx/file.cxx b/sal/osl/unx/file.cxx
index 0ee0b8887dd4..e961c36c7662 100644
--- a/sal/osl/unx/file.cxx
+++ b/sal/osl/unx/file.cxx
@@ -493,7 +493,7 @@ oslFileError FileHandle_Impl::writeFileAt(
 
             if (nBytesToWrite >= m_bufsiz)
             {
-                // buffer to small, write through to file
+                // buffer too small, write through to file
                 sal_uInt64 uDone = 0;
                 result = writeAt(nOffset, &(buffer[*pBytesWritten]), nBytesToWrite, &uDone);
                 if (result != osl_File_E_None)
diff --git a/sal/osl/unx/nlsupport.cxx b/sal/osl/unx/nlsupport.cxx
index 616447ecafe3..9be260b6dd03 100644
--- a/sal/osl/unx/nlsupport.cxx
+++ b/sal/osl/unx/nlsupport.cxx
@@ -245,8 +245,8 @@ static rtl_Locale * parse_locale( const char * locale )
 /*
  * _nl_language_list[] is an array list of supported encodings. Because
  * we are using a binary search, the list has to be in ascending order.
- * We are comparing the encodings case insensitiv, so the list has
- * to be completely upper- , or lowercase.
+ * We are comparing the encodings case insensitive, so the list has
+ * to be completely upper or lowercase.
  */
 
 #if defined(__sun)
diff --git a/sal/osl/unx/time.cxx b/sal/osl/unx/time.cxx
index 4bd3003ef7d5..490865d9a859 100644
--- a/sal/osl/unx/time.cxx
+++ b/sal/osl/unx/time.cxx
@@ -167,7 +167,7 @@ sal_Bool SAL_CALL osl_getTimeValueFromDateTime( const oslDateTime* pDateTime, Ti
         /* check if daylight saving time is in effect */
         bias = aTime.tm_isdst > 0 ? altzone : timezone;
 #else
-        /* exspect daylight saving time to be one hour */
+        /* expect daylight saving time to be one hour */
         bias = aTime.tm_isdst > 0 ? timezone - 3600 : timezone;
 #endif
 
@@ -243,7 +243,7 @@ sal_Bool SAL_CALL osl_getSystemTimeFromLocalTime( const TimeValue* pLocalTimeVal
     /* check if daylight saving time is in effect */
     bias = pLocalTime->tm_isdst > 0 ? altzone : timezone;
 #else
-    /* exspect daylight saving time to be one hour */
+    /* expect daylight saving time to be one hour */
     bias = pLocalTime->tm_isdst > 0 ? timezone - 3600 : timezone;
 #endif
 
diff --git a/sal/osl/w32/file_url.cxx b/sal/osl/w32/file_url.cxx
index 65bcd70552ed..bed0e734d7c3 100644
--- a/sal/osl/w32/file_url.cxx
+++ b/sal/osl/w32/file_url.cxx
@@ -121,8 +121,8 @@ static bool IsValidFilePathComponent(
             cLast = *lpCurrent++;
         }
 
-        /*  If we don't reached the end of the component the length of the component was to long
-            ( See condition of while loop ) */
+        /*  If we don't reached the end of the component the length of the component was too long
+            (See condition of while loop) */
         if ( !lpComponentEnd )
         {
             bValid = false;
diff --git a/sal/osl/w32/module.cxx b/sal/osl/w32/module.cxx
index 104a82826b94..6794fb512c87 100644
--- a/sal/osl/w32/module.cxx
+++ b/sal/osl/w32/module.cxx
@@ -61,7 +61,7 @@ oslModule SAL_CALL osl_loadModule(rtl_uString *strModuleName, sal_Int32 /*nRtldM
 
     // In case of long path names (\\?\c:\...) try to shorten the filename.
     // LoadLibrary cannot handle file names which exceed 260 letters.
-    // In case the path is to long, the function will fail. However, the error
+    // In case the path is too long, the function will fail. However, the error
     // code can be different. For example, it returned  ERROR_FILENAME_EXCED_RANGE
     // on Windows XP and ERROR_INSUFFICIENT_BUFFER on Windows 7 (64bit)
     if (h == nullptr && Module->length > 260)
diff --git a/sal/qa/osl/process/osl_Thread.cxx b/sal/qa/osl/process/osl_Thread.cxx
index 5d63f64032b6..0b97d0b95d8c 100644
--- a/sal/qa/osl/process/osl_Thread.cxx
+++ b/sal/qa/osl/process/osl_Thread.cxx
@@ -1556,7 +1556,7 @@ namespace osl_Thread
                 // resumeAndWaitThread(aThread);
                 t_print("      value = %d\n", static_cast<int>(nValue));
                 t_print("later value = %d\n", static_cast<int>(nLaterValue));
-                // if value and latervalue not equal, than the thread would not suspended
+                // if value and latervalue not equal, then the thread would not suspended
 
                 CPPUNIT_ASSERT_EQUAL_MESSAGE(
                     "Schedule: suspend works.",
diff --git a/sal/qa/osl/process/osl_process.cxx b/sal/qa/osl/process/osl_process.cxx
index f08777d4f1ac..6ba730af5cd6 100644
--- a/sal/qa/osl/process/osl_process.cxx
+++ b/sal/qa/osl/process/osl_process.cxx
@@ -302,7 +302,7 @@ public:
 
     // test that parent and child process have the
     // same environment when osl_executeProcess will
-    // be called with out setting new environment
+    // be called without setting new environment
     // variables
    void osl_execProc_parent_equals_child_environment()
     {
diff --git a/sal/rtl/string.cxx b/sal/rtl/string.cxx
index 3429154e42ed..1d2c5488a15a 100644
--- a/sal/rtl/string.cxx
+++ b/sal/rtl/string.cxx
@@ -211,7 +211,7 @@ static bool rtl_impl_convertUStringToString(rtl_String ** pTarget,
         sal_Size                    nMaxCharLen;
 
         /* Optimization for UTF-8 - we try to calculate the exact length */
-        /* For all other encoding we try an good estimation */
+        /* For all other encoding we try a good estimation */
         if ( nEncoding == RTL_TEXTENCODING_UTF8 )
         {
             nNewLen = rtl_ImplGetFastUTF8ByteLen( pSource, nLength );
diff --git a/sal/textenc/convertsimple.cxx b/sal/textenc/convertsimple.cxx
index 9eb6b928021c..386c77ba80a8 100644
--- a/sal/textenc/convertsimple.cxx
+++ b/sal/textenc/convertsimple.cxx
@@ -32,7 +32,7 @@ static ImplReplaceCharData const aImplRepCharTab[] =
   { 0x00A1, 0x0021 },   /* INVERTED EXCLAMATION MARK */
   { 0x00B7, 0x0045 },   /* MIDDLE DOT */
   { 0x00BF, 0x003F },   /* INVERTED QUESTION MARK */
-  { 0x00D7, 0x002A },   /* MULTIPLIKATION SIGN */
+  { 0x00D7, 0x002A },   /* MULTIPLICATION SIGN */
   { 0x00F7, 0x002F },   /* DIVISION SIGN */
   { 0x2000, 0x0020 },   /* EN QUAD */
   { 0x2001, 0x0020 },   /* EM QUAD */
diff --git a/sal/textenc/tcvtjp2.tab b/sal/textenc/tcvtjp2.tab
index 19105511f273..fc9b0a3d98d7 100644
--- a/sal/textenc/tcvtjp2.tab
+++ b/sal/textenc/tcvtjp2.tab
@@ -23,10 +23,10 @@
 
 /* ======================================================================= */
 
-/* 0x00A2 --> 0x8191 - APPLE_JAPANESE, but I think, this extension is better than the replacment char */
-/* 0x00A3 --> 0x8192 - APPLE_JAPANESE, but I think, this extension is better than the replacment char */
-/* 0x00A5 --> 0x005C - APPLE_JAPANESE, but I think, this extension is better than the replacment char */
-/* 0x00AC --> 0x81CA - APPLE_JAPANESE/SJIS, but I think, this extension is better than the replacment char */
+/* 0x00A2 --> 0x8191 - APPLE_JAPANESE, but I think, this extension is better than the replacement char */
+/* 0x00A3 --> 0x8192 - APPLE_JAPANESE, but I think, this extension is better than the replacement char */
+/* 0x00A5 --> 0x005C - APPLE_JAPANESE, but I think, this extension is better than the replacement char */
+/* 0x00AC --> 0x81CA - APPLE_JAPANESE/SJIS, but I think, this extension is better than the replacement char */
 
 static sal_uInt16 const aImplUniToDBCSTab_SJIS_00[] =
 {
@@ -141,12 +141,12 @@ static sal_uInt16 const aImplUniToDBCSTab_SJIS_04[] =
 
 /* ----------------------------------------------------------------------- */
 
-/* 0x2014 --> 0x815C - APPLE_JAPANESE/SJIS, but I think, this extension is better than the replacment char */
-/* 0x2015 --> 0x815C - MS932, but I think, this extension is better than the replacment char */
-/* 0x2016 --> 0x8161 - APPLE_JAPANESE/SJIS, but I think, this extension is better than the replacment char */
+/* 0x2014 --> 0x815C - APPLE_JAPANESE/SJIS, but I think, this extension is better than the replacement char */
+/* 0x2015 --> 0x815C - MS932, but I think, this extension is better than the replacement char */
+/* 0x2016 --> 0x8161 - APPLE_JAPANESE/SJIS, but I think, this extension is better than the replacement char */
 /* 0x2026 --> 0x8163 - APPLE_JAPANESE is normally 0x00FF (HORIZONTAL ELLIPSIS), because in the APPLE import table 0x8183 is this 0x22EF (MIDLINE HORIZONTAL ELLIPSIS) */
 /*                     but we import this code as 0x2026 */
-/* 0x203E --> 0x8150 - APPLE_JAPANESE, but I think, this extension is better than the replacment char */
+/* 0x203E --> 0x8150 - APPLE_JAPANESE, but I think, this extension is better than the replacement char */
 /*                     in SJIS this is 0x7E, but we import 0x7E as 0x7E, so this would be the better way */
 
 static sal_uInt16 const aImplUniToDBCSTab_SJIS_20[] =
@@ -446,8 +446,8 @@ static sal_uInt16 const aImplUniToDBCSTab_APPLEJAPANESE_27[] =
 /* ----------------------------------------------------------------------- */
 
 /* 0x3014 --> 0x8160 - come from SJIS */
-/* 0x301D --> 0x8780 - MS932, but I think, this extension is better than the replacment char */
-/* 0x301F --> 0x8781 - MS932, but I think, this extension is better than the replacment char */
+/* 0x301D --> 0x8780 - MS932, but I think, this extension is better than the replacement char */
+/* 0x301F --> 0x8781 - MS932, but I think, this extension is better than the replacement char */
 
 static sal_uInt16 const aImplUniToDBCSTab_SJIS_30[] =
 {
diff --git a/sal/textenc/tcvtmb.cxx b/sal/textenc/tcvtmb.cxx
index b5b6903a1d40..6faa56b7c362 100644
--- a/sal/textenc/tcvtmb.cxx
+++ b/sal/textenc/tcvtmb.cxx
@@ -389,7 +389,7 @@ sal_Size ImplEUCJPToUnicode( const void* pData,
             /* 8E + A1-DF */
             if ( c == 0x8E )
             {
-                /* Source buffer to small */
+                /* Source buffer too small */
                 if ( pSrcBuf + 1 == pEndSrcBuf )
                 {
                     *pInfo |= RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOOSMALL;
@@ -413,7 +413,7 @@ sal_Size ImplEUCJPToUnicode( const void* pData,
                 /* 8F + A1-FE + A1-FE */
                 if ( c == 0x8F )
                 {
-                    /* Source buffer to small */
+                    /* Source buffer too small */
                     if (pEndSrcBuf - pSrcBuf < 3)
                     {
                         *pInfo |= RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOOSMALL;
@@ -430,7 +430,7 @@ sal_Size ImplEUCJPToUnicode( const void* pData,
                 /* A1-FE + A1-FE */
                 else
                 {
-                    /* Source buffer to small */
+                    /* Source buffer too small */
                     if ( pSrcBuf + 1 == pEndSrcBuf )
                     {
                         *pInfo |= RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOOSMALL;
diff --git a/sal/textenc/tcvtutf7.cxx b/sal/textenc/tcvtutf7.cxx
index 6c0625d0016e..46c135859566 100644
--- a/sal/textenc/tcvtutf7.cxx
+++ b/sal/textenc/tcvtutf7.cxx
@@ -43,7 +43,7 @@ static unsigned char const aImplBase64Tab[64] =
     0x38, 0x39, 0x2B, 0x2F
 };
 
-/* Index in Base64Tab or 0xFF, when is a invalid character */
+/* Index in Base64Tab or 0xFF, when is an invalid character */
 static unsigned char const aImplBase64IndexTab[128] =
 {
     0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,     /* 0x00-0x07 */
@@ -246,7 +246,7 @@ sal_Size ImplUTF7ToUnicode( SAL_UNUSED_PARAMETER const void*, void* pContext,
                 if ( !bWroteOne )
                 {
                     /* When no more bytes in the source buffer, then */
-                    /* this buffer may be to small */
+                    /* this buffer may be too small */
                     if ( bEnd )
                         *pInfo |= RTL_TEXTTOUNICODE_INFO_ERROR | RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOOSMALL;
                     else
@@ -295,7 +295,7 @@ sal_Size ImplUTF7ToUnicode( SAL_UNUSED_PARAMETER const void*, void* pContext,
                 if ( nBufferBits && nBitBuffer )
                 {
                     /* When no more bytes in the source buffer, then */
-                    /* this buffer may be to small */
+                    /* this buffer may be too small */
                     if ( bEnd )
                         *pInfo |= RTL_TEXTTOUNICODE_INFO_ERROR | RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOOSMALL;
                     else
diff --git a/sal/textenc/tencinfo.cxx b/sal/textenc/tencinfo.cxx
index edbbec9c18dd..f541fcb20004 100644
--- a/sal/textenc/tencinfo.cxx
+++ b/sal/textenc/tencinfo.cxx
@@ -205,7 +205,7 @@ rtl_TextEncoding SAL_CALL rtl_getTextEncodingFromUnixCharset( const sal_Char* pU
 
     /* All Identifiers in the tables are lower case The function search */
     /* for the first matching string in the tables. */
-    /* Sort order: unique (first 14, than 1), important */
+    /* Sort order: unique (first 14, then 1), important */
 
     static ImplStrCharsetDef const aUnixCharsetISOTab[] =
     {
@@ -522,7 +522,7 @@ rtl_TextEncoding SAL_CALL rtl_getTextEncodingFromMimeCharset( const sal_Char* pM
     /* All Identifiers are in lower case and contain only alphanumeric */
     /* characters. The function search for the first matching string in */
     /* the table. */
-    /* Sort order: unique (first iso885914, than iso88591), important */
+    /* Sort order: unique (first iso885914, then iso88591), important */
     static ImplStrCharsetDef const aMimeCharsetTab[] =
     {
         { "unicode11utf7", RTL_TEXTENCODING_UTF7 },
diff --git a/sal/textenc/textenc.cxx b/sal/textenc/textenc.cxx
index 42b6848beb35..7c9592c2e7a8 100644
--- a/sal/textenc/textenc.cxx
+++ b/sal/textenc/textenc.cxx
@@ -261,7 +261,7 @@ static ImplTextEncodingData const aImplISO88591TextEncodingData
 /* 7-Bit ASCII */
 /* 1-Byte, 0x00-0x7F ASCII without exception */
 /* For the import we use ISO-8859-1 with MS extension (MS-1252), because */
-/* when the 8-Bit is set, the chance, that this is a ISO-8859-1 character */
+/* when the 8-Bit is set, the chance, that this is an ISO-8859-1 character */
 /* is the greatest. For the export all chars greater than 127 are not */
 /* converted and are replaced by the replacement character. */
 /* Last-Changes from us: */
diff --git a/sw/qa/extras/rtfexport/rtfexport4.cxx b/sw/qa/extras/rtfexport/rtfexport4.cxx
index 59ce2b0b3bb5..253c3b3b4735 100644
--- a/sw/qa/extras/rtfexport/rtfexport4.cxx
+++ b/sw/qa/extras/rtfexport/rtfexport4.cxx
@@ -159,7 +159,7 @@ DECLARE_OOXMLEXPORT_EXPORTONLY_TEST(testTbrlFrame, "tbrl-frame.odt")
     // Without the accompanying fix in place, this test would have failed with:
     // - Expected: 2
     // - Actual  : 0
-    // i.e. custom wrting mode was lost.
+    // i.e. custom writing mode was lost.
     CPPUNIT_ASSERT_EQUAL(text::WritingMode2::TB_RL, nActual);
 }
 


More information about the Libreoffice-commits mailing list
diff --git a/sal/qa/osl/mutex/osl_Mutex.cxx b/sal/qa/osl/mutex/osl_Mutex.cxx
index d0b7b85b03b1..d0b8283c68e3 100644
--- a/sal/qa/osl/mutex/osl_Mutex.cxx
+++ b/sal/qa/osl/mutex/osl_Mutex.cxx
@@ -253,7 +253,7 @@ namespace osl_Mutex
 
         /** Create two threads to write data to the same buffer, use Mutex to assure
             during one thread write data five times, the other thread should not begin writing.
-            the two threads wrote two different datas: their thread ID, so we can check the datas
+            the two threads wrote two different data: their thread ID, so we can check the data
             in buffer to know the order of the two threads writing
         */
         void ctor_001()
@@ -270,7 +270,7 @@ namespace osl_Mutex
 
             bool bRes = false;
 
             // every 5 datas should the same
             // LLA: this is not a good check, it's too fix
             if (m_Data.buffer[0] == m_Data.buffer[1] &&
                 m_Data.buffer[1] == m_Data.buffer[2] &&
@@ -309,7 +309,7 @@ namespace osl_Mutex
 
             bool bRes = false;
 
             // every 5 datas should the same
             if ( ( m_Res.data1 == 0 ) && ( m_Res.data2 == 3 ) )
                 bRes = true;
 
@@ -270,7 +270,7 @@ namespace osl_Mutex
             bool bRes = false;
 
-            // every 5 datas should the same
+            // every 5 data should the same
             // LLA: this is not a good check, it's too fix
             if (m_Data.buffer[0] == m_Data.buffer[1] &&
@@ -309,7 +309,7 @@ namespace osl_Mutex
             bool bRes = false;
 
-            // every 5 datas should the same
+            // every 5 data should the same
             if ( ( m_Res.data1 == 0 ) && ( m_Res.data2 == 3 ) )
                 bRes = true;